@@ -4,6 +4,7 @@
 APP_TITLE="pyKake"
 APP_VERSION="0.5.0"
 CONFPATH = "/apps/Maemo/%s/" % APP_TITLE.lower()
+LOGO = '/opt/pykake/pykake.png'
 
 import gtk
 import hildon
@@ -194,7 +195,7 @@ class pykakeGui:
 	    else:
 		self.buttMod2sec.hide()
 	except Exception:
-	    print "No button for Mod2sec in current window"
+	    pass
 
     # MAIN MENU
     def mainMenu(self):
@@ -326,7 +327,7 @@ class pykakeGui:
 	about.set_copyright("Copyright 2010 Janne Pekkala")
 	about.set_authors(["Janne Pekkala <yabbapappa@gmail.com>",""])
 	about.set_artists(["Icon: Tomi Taipaleenmäki",""])
-	#about.set_logo(gtk.pixbuf_new_from_file(LOGO))
+	about.set_logo(gtk.gdk.pixbuf_new_from_file(LOGO))
 	about.set_comments("All logos and trademarks are property of their respective owners and are used for informational purposes only.")
 	about.set_license( """This program is free software: you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
